@@ -1,5 +1,5 @@
 from realtimelog.log import Client
 
 __all__ = [
-    "Client",
+    'Client',
 ]
